@@ -5,7 +5,7 @@
 # This program is free software; you can redistribute it and/or
 # modify it under the same terms as Perl itself.
 
-# Version: $Id: Body.pm,v 1.8 2001/09/03 07:47:49 parkerpine Exp $
+# Version: $Id: Body.pm,v 1.9 2001/09/09 09:03:59 parkerpine Exp $
 
 package Mail::MboxParser::Mail::Body;
 
@@ -16,7 +16,7 @@ use Carp;
 use strict;
 use base qw(Exporter);
 use vars qw($VERSION @EXPORT @ISA $AUTOLOAD $_HAVE_NOT_URI_FIND);
-$VERSION 	= "0.03";
+$VERSION 	= "0.04";
 @EXPORT  	= qw();
 @ISA	 	= qw(Mail::MboxParser::Base Mail::MboxParser::Mail);
 $^W++;
@@ -37,12 +37,11 @@ sub init(@) {
 
 sub as_string() {	
 	my $self = shift;
-	if (defined $self->{ARGS}->{decode} &&
-		($self->{ARGS}->{decode} eq 'BODY' ||
-		 $self->{ARGS}->{decode} eq 'ALL')) {
+    $self->reset_last;
+    my $decode = $self->{ARGS}->{decode} || 'NEVER';
+	if ($decode eq 'BODY' || $decode eq 'ALL') {
 		use MIME::QuotedPrint;
-		return 
-			join "", map { $_ = decode_qp($_) } @{$self->{CONTENT}};
+		return join "", map { decode_qp($_) } @{$self->{CONTENT}};
 	}
 	return join "", @{$self->{CONTENT}};
 }
@@ -50,11 +49,11 @@ sub as_string() {
 
 sub as_lines() { 
 	my $self = shift;
-	if (defined $self->{ARGS}->{decode} &&
-		($self->{ARGS}->{decode} eq 'BODY' ||
-		 $self->{ARGS}->{decode} eq 'ALL')) {
+    $self->reset_last;
+    my $decode = $self->{ARGS}->{decode} || 'NEVER';
+	if ($decode eq 'BODY' || $decode eq 'ALL') {
 		use MIME::QuotedPrint; 
-		return map { $_ = decode_qp($_) } @{$self->{CONTENT}};
+		return map { decode_qp($_) } @{$self->{CONTENT}};
 	}
 	return @{$self->{CONTENT}};
 }
@@ -63,6 +62,7 @@ sub as_lines() {
 sub signature() {
 	my $self = shift;
 	$self->reset_last;
+    my $decode = $self->{ARGS}->{decode} || 'NEVER';
 	my $bound = $self->{BOUNDARY};
 	
 	my @signature;
@@ -73,9 +73,11 @@ sub signature() {
 		if (! /^--\040?[\r\n]?$/ && not $seperator) {
 			next;
 		}
-		
+        
 		# we hit the signature delimiter (--)
 		elsif (not $seperator) { $seperator = 1; next }
+        
+	    chomp;	
 
 		# we are inside signature: is line perhaps MIME-boundary?
 		last if $bound && /^--\Q$bound\E/ && $seperator;
@@ -85,7 +87,10 @@ sub signature() {
 	}
 	
 	$self->{LAST_ERR} = "No signature found" if @signature == 0;
-	map { chomp } @signature;
+    if ($decode eq 'BODY' || $decode eq 'ALL') {
+        use MIME::QuotedPrint;
+	    map { $_ = decode_qp($_) } @signature;
+    }
 	return @signature if $seperator;
 	return ();
 }
@@ -126,6 +131,7 @@ else {
 
 sub quotes() {
 	my $self = shift;
+    my $decode = $self->{ARGS}->{decode} || 'NEVER';
 	$self->reset_last;
 	
 	my %ret;
@@ -134,7 +140,12 @@ sub quotes() {
 	my $last 	= 0; # num of quotes in last line
 	
 	for (@{$self->{CONTENT}}) {
-	
+	    
+        if ($decode eq 'ALL' || $decode eq 'BODY') {
+            use MIME::QuotedPrint;
+            $_ = decode_qp($_);
+        }
+        
 		# count quotation signs
 		$q = 0;
 		my $t = "a" x length;
@@ -178,13 +189,89 @@ Mail::MboxParser::Mail::Body - rudimentary mail-body object
 
 =head1 SYNOPSIS
 
-See L<Mail::MboxParser> for examples on usage and description of the provided methods.
+    use Mail::MboxParser;
 
+    [...]
+
+    # $msg is a Mail::MboxParser::Mail
+    my $body = $msg->body(0);
+
+    # or preferably
+
+    my $body = $msg->body($msg->find_body);
+
+    for my $line ($body->signature) { print $line, "\n" }
+    for my $url ($body->extract_urls(unique => 1)) {
+        print $url->{url}, "\n";
+        print $url->{context}, "\n";
+    }
+        
 =head1 DESCRIPTION
 
 This class represents the body of an email-message. 
 Since emails can have multiple MIME-parts and each of these parts has a body it is not always easy to say which part actually holds the text of the message (if there is any at all). Mail::MboxParser::Mail::find_body will help and suggest a part.
 
+=head1 METHODS
+
+=over 4
+
+=item B<as_string>
+
+Returns the textual representation of the body as one string. Decoding takes place when the mailbox has been opened using the decode => 'HEADER' | 'ALL' option.
+
+=item B<as_lines>
+
+Sames as as_string() just that you get an array of lines.
+
+=item B<signature>
+
+Returns the signature of a message as an array of lines. Trailing newlines are already removed.
+
+$body->error returns a string if no signature has been found.
+
+=item B<extract_urls>
+
+=item B<extract_urls (unique =E<gt> 1)>
+
+Returns an array of hash-refs. Each hash-ref has two fields: 'url' and 'context' where context is the line in which the 'url' appeared.
+
+When calling it like $mail->extract_urls(unique => 1), duplicate URLs will be filtered out regardless of the 'context'. That's useful if you just want a list of all URLs that can be found in your mails.
+
+$body->error() will return a string if no URLs could be found within the body.
+
+=item B<quotes>
+
+Returns a hash-ref of array-refs where the hash-keys are the several levels of quotation. Each array-element contains the paragraphs of this quotation-level as one string. Example:
+
+	my $quotes = $msg->body($msg->find_body)->quotes;
+	print $quotes->{1}->[0], "\n";
+	print $quotes->{0}->[0], "\n";
+
+This should print the first paragraph of the mail-body that has been quoted once and below that the paragraph that supposedly is the reply to this paragraph. Perhaps thus:
+
+	> I had been trying to work with the CGI module 
+	> but I didn't yet fully understand it.
+
+	Ah, it is tricky. Have you read the CGI-FAQ that 
+	comes with the module?
+
+Mark that empty lines will not be ignored and are part of the lines contained in the array of $quotes->{0}.
+
+So below is a little code-snippet that should, in most cases, restore the first 5 paragraphs (containing quote-level 0 and 1) of an email:
+
+	for (0 .. 5) {
+		print $quotes->{0}->[$_];
+		print $quotes->{1}->[$_];
+	}
+
+Since quotes() considers an empty line between two quotes paragraphs as a paragraph in $quotes->{0}, the paragraphs with one quote and those with zero are balanced. That means: 
+
+scalar @{$quotes->{0}} - DIFF == scalar @{$quotes->{1}} where DIFF is element of {-1, 0, 1}.
+
+Unfortunately, quotes() can up to now only deal with '>' as quotation-marks.
+
+=back
+
 =head1 AUTHOR AND COPYRIGHT
 
 Tassilo von Parseval <Tassilo.Parseval@post.RWTH-Aachen.de>.
@@ -195,5 +282,4 @@ modify it under the same terms as Perl itself.
 
 =head1 SEE ALSO
 
-L<Mail::MboxParser::Mail> to learn how to use MIME::Entity-stuff easily
-
+=cut
